
//                     * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
//                     * * * * *    Commande NEMA 17 avec AccelStepper     * * * * *
//                     * * * * *     Moteur piloté par driver DRV8825      * * * * *
//                     * * * * *              et micro steps               * * * * *
//                     * * * * *        Pour transbodeur vertical          * * * * *
//                     * * * * *                                           * * * * *
//                     * * * * *           Programme opérationnel          * * * * *
//                     * * * * *   Avec commutateur mOm de sélection et    * * * * *
//                     * * * * *       affichage LCD  et suivi Leds        * * * * *
//                     * * * * *                sur Méga                   * * * * *
//                     * * * * *       Commande de deux moteurs PaP        * * * * *
//                     * * * * * avec deux drivers branchés en parallèle   * * * * *
//                     * * * * *    sur les même sorties de l'arduino      * * * * *
//                     * * * * *                                           * * * * *
//                     * * * * *   avec commande servo de verrouillage     * * * * *
//                     * * * * *          et témoin de position            * * * * *
//                     * * * * *                                           * * * * *
//                     * * * * *    Mise en mémoire des niveaux de voie    * * * * *
//                     * * * * *    et de la dernière sélection de voie    * * * * *
//                     * * * * *                                           * * * * *      
//                     * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

#include <EEPROM.h>
#include <AccelStepper.h>
#include <Wire.h>
#include <LiquidCrystal_I2C.h>  

LiquidCrystal_I2C lcd(0x27,16,2);    // Description de l'écran
    
  const byte PinBPplus  = 16;        // Pin d'entrée des boutons de commande
  const byte PinBPmoins = 15;
  const byte PinBPConf  = 14;
  const byte PinBPajustmem = 2;

  int Voie  = 0;
  int VoieInt = 0;
  int VoieSel = 0;
  int VoieAnc = 0;
  boolean act  = false;
  boolean Confirm = false ;
  boolean mem = false ;
  
      /* Affectation des sorties pour les LEDs témoins  */
  int pinLed [11] = {40,42,44,46,48,39,41,43,45,47,49};
  const byte pinAlimLed = 38 ;

  unsigned long TempsZero = 0 ;
  boolean Veille = true ;

// Définit comment sera piloté le moteur et les broches qu'il utilise .
   AccelStepper Moteur1(1, 11, 10); // 1=Driver, Pin 11 = pas, Pin 10 = direction
    
//  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *   
// 
//                   Définition des hauteur de voies en pas moteur
//                    microstep = 1/2  soit 400 pas pour 1.25 mm
//                    Hauteur entre voie de 80 mm soit 25600 pas

 unsigned long NiveauVoie [11] = {0,25600,51200,76800,102400,128000,153600,179200,204800,230400,256000};
 unsigned long Niveaumod ;
//  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
     
    const byte pinZero = 5 ;         // pin d'entrée du détecteur de fin de course niveau zéro
    const byte pinZeroApp = 4 ;      // pin d'entrée du détecteur d'approche de fin de course
    const byte pinAlim = 23 ;        // pin de sortie commendant le relai d'alimentation 12v des moteurs
    const byte pinDCC = 3 ;          // pin de sortie commendant le relai d'alimentation DCC de la rampe
    const byte pinServo = 25 ;       // pin de commande du servo de verrouillage "Pont-voie"
    const byte pinVerrou = 27 ;      // pin témoin de verroillage - déverrouilage du servo
    const byte pinDriverHT = 13;     // vrai = driver désactivé
    const byte pinM0 = 8 ;           //  Gestion des micro Steps
    const byte pinM1 = 7 ;           //  Gestion des micro Steps
    const byte pinM2 = 6 ;           //  Gestion des micro Steps
    boolean Approch = false ;
    long Ralenti = 0 ;
    boolean ini = true ;        //  Initialisation pour définir le zéro de référence (et autre)
    boolean Mvt ;                //  vrai si le moteur tourne
    boolean Alim12v = false ;    //  Définit l'alimentation en 12v des moteurs PaP
    boolean AlimLED = false ;    //  Commande l'alimentation des Leds
    boolean Verrouille = false;  //  Témoin de verrouillage
    boolean Attente = false ;
    unsigned long Clignot = 0 ;
    byte y ;                      //  variables d'incrémentation
    
    
void setup()
   {  
      lcd.init();
      lcd.backlight();
      lcd.setCursor(0,0);
      
      for (y=0 ; y <= 10 ; y++){ pinMode(pinLed [y], OUTPUT); }
      for (y=0 ; y <= 10 ; y++){ digitalWrite(pinLed [y], LOW); }
      pinMode(pinAlimLed,OUTPUT);
      pinMode(PinBPplus,INPUT);
      pinMode(PinBPmoins,INPUT);
      pinMode(PinBPConf,INPUT);
      pinMode(PinBPajustmem,INPUT);
    
      pinMode (pinZero, INPUT) ;
      pinMode (pinZeroApp, INPUT) ;
      pinMode(pinDriverHT, OUTPUT);
      pinMode(pinM0, OUTPUT) ;
      pinMode(pinM1, OUTPUT) ;
      pinMode(pinM2, OUTPUT) ;
      pinMode(pinAlim, OUTPUT) ;
      pinMode(pinDCC, OUTPUT) ;
      pinMode(pinServo, OUTPUT) ;
      pinMode (pinVerrou, INPUT) ;
    
// * * * * Réglage microsteps  * * * *         M0     M1     M2   
                                      //       LOW    LOW    LOW      Full step 
      digitalWrite(pinM0,HIGH);       //       HIGH   LOW    LOW      1/2  pas
      digitalWrite(pinM1,LOW);        //       LOW    HIGH   LOW      1/4  pas
      digitalWrite(pinM2,LOW);        //       HIGH   HIGH   LOW      1/8  pas
                                      //       LOW    LOW    HIGH     1/16 pas
// * * * * * * * * * * * * * * * * * *         LOW    HIGH   HIGH     1/32 pas

      digitalWrite(pinDriverHT,HIGH);
      digitalWrite(pinDCC,HIGH);
      digitalWrite(pinServo,LOW);
      digitalWrite( pinAlim,LOW );
      delay (3000) ;                   // Attend que l'initialisation du Nano Servo soit faite
      
      premierefois () ;
      lectureEP () ;
      Initialisation() ;
    }  

void loop()
    {
     affichage(5) ;
     if (!Mvt){ SelecVoie() ; }
     if (Mvt){ Deplacement () ; }
    }





   
